@@ -1,31 +1,26 @@
 package Data::Serializer::YAML;
 BEGIN { @Data::Serializer::YAML::ISA = qw(Data::Serializer) }
 
-
+use warnings;
 use strict;
 use YAML;
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
+use vars qw($VERSION @ISA);
 
-require Exporter;
-require AutoLoader;
+$VERSION = '0.02';
 
-@ISA = qw(Exporter AutoLoader);
-# Items to export into callers namespace by default. Note: do not export
-# names by default without a very good reason. Use EXPORT_OK instead.
-# Do not simply export all your public functions/methods/constants.
-@EXPORT = qw(
-	
-);
-$VERSION = '0.01';
+sub serialize {
+    return Dump($_[1]);
+}
+
+sub deserialize {
+    return Load($_[1]);
+}
 
 
-# Preloaded methods go here.
-
-# Autoload methods go after =cut, and are processed by the autosplit program.
 
 1;
 __END__
-# Below is the stub of documentation for your module. You better edit it!
+#
 
 =head1 NAME
 
@@ -39,6 +34,15 @@ Data::Serializer::YAML - Creates bridge between Data::Serializer and YAML
 
 Module is used internally to Data::Serializer
 
+
+=over 4
+
+=item B<serialize> - Wrapper to normalize serializer method name
+
+=item B<deserialize> - Wrapper to normalize deserializer method name
+
+=back
+
 =head1 AUTHOR
 
 Florian Helmberger <fh@laudatio.com>
@@ -55,10 +59,3 @@ perl(1), Data::Serializer(3), YAML(3).
 
 =cut
 
-sub serialize {
-    return Dump($_[1]);
-}
-
-sub deserialize {
-    return Load($_[1]);
-}
